@@ -1,6 +1,6 @@
 package App::duino::Command::build;
 {
-  $App::duino::Command::build::VERSION = '0.05';
+  $App::duino::Command::build::VERSION = '0.06';
 }
 
 use strict;
@@ -11,6 +11,7 @@ use App::duino -command;
 use Text::Template;
 use File::Basename;
 use File::Find::Rule;
+use IPC::Cmd qw(can_run run);
 use File::Path qw(make_path);
 
 =head1 NAME
@@ -19,7 +20,7 @@ App::duino::Command::build - Build an Arduino sketch
 
 =head1 VERSION
 
-version 0.05
+version 0.06
 
 =head1 SYNOPSIS
 
@@ -63,6 +64,8 @@ sub opt_spec {
 sub execute {
 	my ($self, $opt, $args) = @_;
 
+	my $make = can_run('make') or die "Can't find command 'make'.";
+
 	my $board_name    = $opt -> board;
 	my $makefile_name = ".build/$board_name/Makefile";
 
@@ -114,6 +117,7 @@ sub execute {
 	);
 
 	system 'make', '--silent', '-f', $makefile_name;
+	die "Failed to build.\n" unless $? == 0;
 }
 
 =head1 AUTHOR
@@ -246,22 +250,22 @@ LDFLAGS       = -mmcu=$(MCU) -Wl,--gc-sections -Os
 
 # library sources
 $(OBJDIR)/%.o: $(ARDUINO_LIB_PATH)/%.c
-	$(ECHO) 'Building $(shell basename $<)'
+	$(ECHO) 'Building $(notdir $<)'
 	$(MKDIR) $(dir $@)
 	$(CC) -c $(CPPFLAGS) $(CFLAGS) $< -o $@
 
 $(OBJDIR)/%.o: $(ARDUINO_LIB_PATH)/%.cpp
-	$(ECHO) 'Building $(shell basename $<)'
+	$(ECHO) 'Building $(notdir $<)'
 	$(MKDIR) $(dir $@)
 	$(CC) -c $(CPPFLAGS) $(CXXFLAGS) $< -o $@
 
 $(OBJDIR)/%.o: $(USER_LIB_PATH)/%.cpp
-	$(ECHO) 'Building $(shell basename $<)'
+	$(ECHO) 'Building $(notdir $<)'
 	$(MKDIR) $(dir $@)
 	$(CC) -c $(CPPFLAGS) $(CFLAGS) $< -o $@
 
 $(OBJDIR)/%.o: $(USER_LIB_PATH)/%.c
-	$(ECHO) 'Building $(shell basename $<)'
+	$(ECHO) 'Building $(notdir $<)'
 	$(MKDIR) $(dir $@)
 	$(CC) -c $(CPPFLAGS) $(CFLAGS) $< -o $@
 
@@ -269,16 +273,16 @@ $(OBJDIR)/%.o: $(USER_LIB_PATH)/%.c
 # .o rules are for objects, .d for dependency tracking
 # there seems to be an awful lot of duplication here!!!
 $(OBJDIR)/%.o: %.c
-	$(ECHO) 'Building $(shell basename $<)'
+	$(ECHO) 'Building $(notdir $<)'
 	$(CC) -c $(CPPFLAGS) $(CFLAGS) $< -o $@
 
 $(OBJDIR)/%.o: %.cpp
-	$(ECHO) 'Building $(shell basename $<)'
+	$(ECHO) 'Building $(notdir $<)'
 	$(CXX) -c $(CPPFLAGS) $(CXXFLAGS) $< -o $@
 
 # the ino -> cpp -> o file
 $(OBJDIR)/%.cpp: %.ino
-	$(ECHO) 'Building $(shell basename $<)'
+	$(ECHO) 'Building $(notdir $<)'
 	$(MKDIR) $(dir $@)
 	$(ECHO) '#include <Arduino.h>' > $@
 	$(CAT)  $< >> $@
@@ -288,19 +292,21 @@ $(OBJDIR)/%.o: $(OBJDIR)/%.cpp
 
 # core files
 $(OBJDIR)/%.o: $(ARDUINO_CORE_PATH)/%.c
-	$(ECHO) 'Building $(shell basename $<)'
+	$(ECHO) 'Building $(notdir $<)'
 	$(CC) -c $(CPPFLAGS) $(CFLAGS) $< -o $@
 
 $(OBJDIR)/%.o: $(ARDUINO_CORE_PATH)/%.cpp
-	$(ECHO) 'Building $(shell basename $<)'
+	$(ECHO) 'Building $(notdir $<)'
 	$(CXX) -c $(CPPFLAGS) $(CXXFLAGS) $< -o $@
 
 # various object conversions
 $(OBJDIR)/%.hex: $(OBJDIR)/%.elf
-	$(ECHO) 'Building $(shell basename $<)'
+	$(ECHO) 'Generating $(notdir $@)'
 	$(OBJCOPY) -O ihex -R .eeprom $< $@
+	$(ECHO)
 
 all: 		$(OBJDIR) $(TARGET_HEX)
+	$(ECHO) 'Built! Now you can run "duino upload"'
 
 $(OBJDIR):
 		$(MKDIR) $(OBJDIR)
@@ -309,6 +315,7 @@ $(TARGET_ELF): 	$(LOCAL_OBJS) $(CORE_LIB) $(OTHER_OBJS)
 		$(CC) $(LDFLAGS) -o $@ $(LOCAL_OBJS) $(CORE_LIB) $(OTHER_OBJS) -lc -lm
 
 $(CORE_LIB):	$(CORE_OBJS) $(LIB_OBJS) $(USER_LIB_OBJS)
+		$(ECHO) 'Linking $(notdir $(CORE_LIB))'
 		$(AR) rcs $@ $(CORE_OBJS) $(LIB_OBJS) $(USER_LIB_OBJS)
 
 .PHONY: all
